MsDeviceParameter class

Inheritance

Constructors

MsDeviceParameter({required VendorModelInfo vendorModelInfo, required IpAndPort ipAndPort, required Status status, required String numberOfTracks, required String supportsJIS2, required String style, required String msCapabilities})
MsDeviceParameter.fromXML(String xmlSTR)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
ipAndPort → IpAndPort
finalinherited
msCapabilities → String
final
numberOfTracks → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status ↔ Status
getter/setter pairinherited
style → String
final
supportsJIS2 → String
final
vendorModelInfo → VendorModelInfo
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
toXML() → String
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited