MsStatus class

Inheritance

Constructors

MsStatus({required String desc, required String init, required String powerOff, required String ready, required String unknown})
MsStatus.fromXML(String xmlSTR)
factory

Properties

color → Color
no setterinherited
desc → String
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
image → String
no setteroverride
init → String
finalinherited
isInit → bool
no setterinherited
isLocked → bool
no setterinherited
isOff → bool
no setterinherited
isReady → bool
no setterinherited
powerOff → String
finalinherited
ready → String
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
unknown → String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
toXML() → String
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited