PrDeviceParameter class

Inheritance

Constructors

PrDeviceParameter({required VendorModelInfo vendorModelInfo, required IpAndPort ipAndPort, required Status status, required String supportsColor, required List<SupportedStock> supportedStocks})
PrDeviceParameter.fromXML(String xmlSTR)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
ipAndPort → IpAndPort
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status ↔ Status
getter/setter pairinherited
supportedStocks → List<SupportedStock>
final
supportsColor → String
final
vendorModelInfo → VendorModelInfo
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
toXML() → String
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited