ExceptionEvent class

Inheritance

Constructors

ExceptionEvent({required int messageID, required String messageName, required String exceptionSource, required String user, required String device, required String arg, required String workstation, required String applicationVersion, required String applicationName, required String body})
ExceptionEvent.fromXML(String xmlSTR)
factory

Properties

applicationName → String
final
applicationVersion → String
final
arg → String
final
body → String
final
device → String
final
exceptionSource → String
final
hashCode → int
The hash code for this object.
no setterinherited
messageID → int
finalinherited
messageName → String
finalinherited
name → String
finalinherited
notificationType → NotificationType
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
user → String
final
workstation → String
final
xmlns → String
finalinherited
xsi → String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override
toXML() → String
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited