AeaMessage class

Constructors

AeaMessage({required AeaText aeaText, required AeaBinary aeaBinary})
AeaMessage.fromXML(String xmlSTR)
factory

Properties

aeaBinary → AeaBinary
final
aeaText → AeaText
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
toXML() → String

Operators

operator ==(Object other) → bool
The equality operator.
inherited