AeaRequestRequest class

Inheritance

Constructors

AeaRequestRequest({required int messageID, String? xmlns, String? xsi, required List<String> texts, List<String> binaries = const []})
AeaRequestRequest.fromXML(String xmlSTR)
factory

Properties

binaries → List<String>
final
hashCode → int
The hash code for this object.
no setterinherited
isConfiguration → bool
no setter
messageID → int
finalinherited
messageName → String
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
texts → List<String>
final
xmlns → String
finalinherited
xsi → String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override
toXML() → String
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited