DeviceAcquireRequest class

Inheritance

Constructors

DeviceAcquireRequest({String? xmlns, String? xsi, required int messageID, required String deviceName, required String deviceToken, required String airlineID, required String msFoidMasking})
DeviceAcquireRequest.fromXML(String xmlSTR)
factory

Properties

airlineID → String
final
deviceName → String
final
deviceToken → String
final
hashCode → int
The hash code for this object.
no setterinherited
messageID → int
finalinherited
messageName → String
finalinherited
msFoidMasking → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
xmlns → String
finalinherited
xsi → String
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override
toXML() → String
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited