PrintDocument class

Constructors

PrintDocument({required List<String> pdfs, required List<DocumentNode> textDocuments, required String documentID, required String stockName})
PrintDocument.fromXML(String xmlSTR)
factory

Properties

documentID → String
final
hashCode → int
The hash code for this object.
no setterinherited
pdfs → List<String>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stockName → String
final
textDocuments → List<DocumentNode>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
toXML() → String

Operators

operator ==(Object other) → bool
The equality operator.
inherited