InterfaceLevel class

Constructors

InterfaceLevel({required String level, required String wsLocalPath, required String xsdVersion})
InterfaceLevel.fromXML(String xmlSTR)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
level → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
wsLocalPath → String
final
xsdVersion → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override
toXML() → String

Operators

operator ==(Object other) → bool
The equality operator.
inherited