MsData class

Inheritance

Constructors

MsData({required String msType, required String readStatus, required List<MSTrackData> msTrackData})
MsData.fromXML(String xmlSTR)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
msTrackData → List<MSTrackData>
final
msType → String
final
readStatus → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parseData() → Map<String, dynamic>?
toString() → String
A string representation of this object.
override
toXML() → String
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited