PlatformDevices class

Constructors

PlatformDevices({required List<BcDevice> bcDevices, required List<BeDevice> beDevices, required List<BgDevice> bgDevices, required List<BpDevice> bpDevices, required List<BtDevice> btDevices, required List<DdDevice> ddDevices, required List<MsDevice> msDevices, required List<OcDevice> ocDevices, required List<PrDevice> prDevices, required List<ZiDevice> ziDevices, required List<ZlDevice> zlDevices})
PlatformDevices.empty()
factory

Properties

availableDeviceTypes → List<DeviceType>
no setter
bcDevices → List<BcDevice>
final
beDevices → List<BeDevice>
final
bgDevices → List<BgDevice>
final
bpDevices → List<BpDevice>
final
btDevices → List<BtDevice>
final
ddDevices → List<DdDevice>
final
firstDevice → Device?
no setter
hasBC → bool
no setter
hasBE → bool
no setter
hasBG → bool
no setter
hasBP → bool
no setter
hasBT → bool
no setter
hasDD → bool
no setter
hasDevice → bool
no setter
hashCode → int
The hash code for this object.
no setterinherited
hasMS → bool
no setter
hasOC → bool
no setter
hasPR → bool
no setter
hasZI → bool
no setter
hasZL → bool
no setter
msDevices → List<MsDevice>
final
ocDevices → List<OcDevice>
final
prDevices → List<PrDevice>
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
ziDevices → List<ZiDevice>
final
zlDevices → List<ZlDevice>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeDevice(String deviceIndex) → void
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited