Device class

Implementers

Constructors

Device({required String deviceIndex, required String deviceName, required String deviceParameterType, required List<Device> devices, required List<InterfaceMode> supportedInterfaceModes, required DeviceParameter deviceParameter, required SocketService socketService})
Device.fromXML(String xmlSTR)
factory

Properties

acquired ↔ bool
getter/setter pair
currentMessageID → int
no setter
dataAvailable ↔ bool
getter/setter pair
deviceIndex → String
final
deviceName → String
final
deviceParameter ↔ DeviceParameter
getter/setter pair
deviceParameterType → String
final
devices → List<Device>
final
getType → DeviceType
no setter
hashCode → int
The hash code for this object.
no setterinherited
haveLock → bool
no setter
icon → String
no setter
initialized ↔ bool
getter/setter pair
initializing ↔ bool
getter/setter pair
isConfiguring → bool
no setter
isConnected → bool
no setter
isPrinting → bool
no setter
isReader → bool
no setter
locked ↔ bool
getter/setter pair
modded ↔ bool
getter/setter pair
readerRead ↔ bool
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
socketService → SocketService
final
statusMsg ↔ String
getter/setter pair
supportedInterfaceModes → List<InterfaceMode>
final

Methods

acquire() → Future<CuppsCommandResponse>
aeaRequest(String text) → Future<CuppsCommandResponse>
completeConfigure(List<String> commands) → Future<List<CuppsCommandResponse>>
configure(String text) → Future<CuppsCommandResponse>
connect() → Future<CuppsCommandResponse>
disableAutoLock() → dynamic
disableRetry() → void
enableAutoLock() → dynamic
initialize() → Future<CuppsCommandResponse>
interfaceLevel(String level) → Future<CuppsCommandResponse>
interfaceLevelsAvailable() → Future<CuppsCommandResponse>
lock({bool renew = false}) → Future<CuppsCommandResponse>
mode() → Future<CuppsCommandResponse>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onDeviceDisconnect() → dynamic
print(String text) → Future<CuppsCommandResponse>
refreshStatus() → Future<CuppsCommandResponse>
release() → Future<CuppsCommandResponse>
respond({required String xml}) → Future<void>
restart() → Future<CuppsCommandResponse>
send({required String xml}) → Future<String>
setConnectionChecker({Duration timeout = const Duration(seconds: 12), Duration interval = const Duration(seconds: 45), required Function retry}) → void
showDataAvailable() → void
toString() → String
A string representation of this object.
inherited
toXML() → String
unlock() → Future<CuppsCommandResponse>

Operators

operator ==(Object other) → bool
The equality operator.
inherited