DeviceParameter class

Implementers

Constructors

DeviceParameter({required VendorModelInfo vendorModelInfo, required IpAndPort ipAndPort, required Status status})

Properties

hashCode → int
The hash code for this object.
no setterinherited
ipAndPort → IpAndPort
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status ↔ Status
getter/setter pair
vendorModelInfo → VendorModelInfo
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
toXML() → String

Operators

operator ==(Object other) → bool
The equality operator.
inherited