IpAndPort class

Constructors

IpAndPort({required String hostName, required String ip, required String port})
IpAndPort.fromXML(String xmlSTR)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
hostName → String
final
ip → String
final
port → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override
toXML() → String

Operators

operator ==(Object other) → bool
The equality operator.
inherited