Status class

Implementers

Constructors

Status({required String desc, required String init, required String powerOff, required String ready, required String unknown})
Status.fromXML(String xmlSTR)
factory

Properties

color → Color
no setter
desc → String
final
hashCode → int
The hash code for this object.
no setterinherited
image → String
no setter
init → String
final
isInit → bool
no setter
isLocked → bool
no setter
isOff → bool
no setter
isReady → bool
no setter
powerOff → String
final
ready → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
unknown → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override
toXML() → String

Operators

operator ==(Object other) → bool
The equality operator.
inherited