SupportedStock class

Constructors

SupportedStock({required String stockName, required String supportsColor, required String stockWidth, required String stockHeight, required String leftMargin, required String rightMargin, required String topMargin, required String bottomMargin, required String perforationLeft})
SupportedStock.fromXML(String xmlSTR)
factory

Properties

bottomMargin → String
final
hashCode → int
The hash code for this object.
no setterinherited
leftMargin → String
final
perforationLeft → String
final
rightMargin → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stockHeight → String
final
stockName → String
final
stockWidth → String
final
supportsColor → String
final
topMargin → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
toXML() → String

Operators

operator ==(Object other) → bool
The equality operator.
inherited