VendorModelInfo class

Constructors

VendorModelInfo({required String miscInfo, required String model, required String vendor, String? poCapabilities})
VendorModelInfo.fromXML(String xmlSTR)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
miscInfo → String
final
model → String
final
poCapabilities → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
vendor → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
toXML() → String

Operators

operator ==(Object other) → bool
The equality operator.
inherited