LogEntity class

Constructors

LogEntity(String path)

Properties

date → DateTime
no setter
dateStr → String
no setter
hashCode → int
The hash code for this object.
no setterinherited
name → String
no setter
path → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type → String
no setter

Methods

clear() → Future<void>
download() → Future<void>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited